(*:Copyright: Copyright 1988-2003 Wolfram Research, Inc. *)

(*:Mathematica Version: 3.0 *)

(*:Package Version: 1.0 *)

(*:Name: Algebra`SymmComp` *)

(*:Title: Symmetric Composition algebras *) 

(*:Author: Cndido Martn Gonzlez *)

(*:Keywords: spit octonions, Zorn matrices, Para-octonions, Pseudo-octonions *)

(* :Sources: Russian's book: Rings that are nearly associative*)

(*:Summary:
Package for computations with some symmetric compositions algebras*)

BeginPackage["Algebra`SymmComp`"]

p::usage = "Gives the product p[x,y] of the octonions x and y."

rec::usage= "Writes an octonion as a formal linear combinations of elements in the standard 
basis."

B::usage="Standar basis of split Octonions."

cero::usage="cero Zorn matrix."

uno::usage="unit Zorn matrix."

Cayley::usage="Conjugate of octonion."

trace::usage="trace of octonion."

norm::usage="norm of octonion."

avec::usage="octonion to vector."

aoct::usage="vector to octonion."

LinearMap::usage="Linear map with given matrix"

e::usage="Idempotents (needs subscript = 1,2)."

u::usage="Elements in the (1,0) Peirce space (relative to e_1) of Zorn's algebra 
(needs subscript = 1,3)."

v::usage="Elements in the (0,1) Peirce space (relative to e_1) of Zorn's algebra 
(needs subscript = 1,3)."

recT::usage="TeX Form of rec."

paraoctonion::usage="Gives the product paraoctonion[x,y] of elements x,y in
the para-octonions algebra asociated to Zorn matrices algebra"

pseudoctonion::usage="Gives the product pseudoctonion[x,y] of elements x,y in
the pseudo-octonions algebra asociated to Zorn matrices algebra"

b::usage= "Polar form of the octonions norm"

auto::usage="Order-three automorphism of Zorn matrices"

Begin["Algebra`Zorn`Private`"]


p[x_,y_]:={{x[[1,1]]y[[1,1]]+x[[1,2]].y[[2,1]],x[[1,1]]y[[1,2]]+y[[2,2]]x[[1,2]]-Cross[x[[2,1]],
y[[2,1]]]},{y[[1,1]]x[[2,1]]+x[[2,2]]y[[2,1]]+Cross[x[[1,2]],y[[1,2]]],
x[[2,1]].y[[1,2]]+x[[2,2]]y[[2,2]]}};

rec[x_]:=Sum[x[[i,i]] Subscript["e",i],{i,2}]+Sum[x[[1,2]][[i]] Subscript["u",i],{i,3}]+
Sum[x[[2,1]][[i]] Subscript["v",i],{i,3}]

recT[x_]:=TeXForm[rec[x]]

B={{{1,{0,0,0}},{{0,0,0},0}},
{{0,{0,0,0}},{{0,0,0},1}},
{{0,{1,0,0}},{{0,0,0},0}},
{{0,{0,1,0}},{{0,0,0},0}},
{{0,{0,0,1}},{{0,0,0},0}},
{{0,{0,0,0}},{{1,0,0},0}},
{{0,{0,0,0}},{{0,1,0},0}},
{{0,{0,0,0}},{{0,0,1},0}}}

Do[Subscript[e,i]=B[[i]],{i,2}]

Do[Subscript[u,i]=B[[2+i]],{i,3}]

Do[Subscript[v,i]=B[[5+i]],{i,3}]

cero={{0,{0,0,0}},{{0,0,0},0}}

uno={{1,{0,0,0}},{{0,0,0},1}}

Cayley[x_]:={{x[[2,2]],-x[[1,2]]},{-x[[2,1]],x[[1,1]]}}

trace[x_]:=Expand[x+Cayley[x]][[1,1]]

norm[x_]:=Expand[p[x,Cayley[x]]][[1,1]]

avec[x_]:={x[[1,1]],x[[2,2]],x[[1,2]][[1]],x[[1,2]][[2]],x[[1,2]][[3]],x[[2,1]][[1]],
x[[2,1]][[2]],x[[2,1]][[3]]}

aoct[x_]:={{x[[1]],{x[[3]],x[[4]],x[[5]]}},{{x[[6]],x[[7]],x[[8]]},x[[2]]}}

LinearMap[M_,x_]:=aoct[M.avec[x]]//Expand

paraoctonion[x_,y_]:=p[Cayley[x],Cayley[y]]

b[x_,y_]:=Expand[norm[x+y]-norm[x]-norm[y]]

auto[x_]:={
{x[[1,1]],{x[[1,2]][[3]],x[[1,2]][[1]],x[[1,2]][[2]]}},
{{x[[2,1]][[3]],x[[2,1]][[1]],x[[2,1]][[2]]},x[[2,2]]}}

pseudoctonion[x_,y_]:=p[auto[Cayley[x]],auto[auto[Cayley[y]]]]

End[]  (* Algebra`SymmComp`Private` *)


EndPackage[]  (* Algebra`SymmComp` *)

            
